/*****************************************************  Device Defaults  ******************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following defaults are assigned to structures defined in the device functions header.

	Rev History: 2-20-2014:		Inital release.

	Copyright 2014, Red Rapids, Inc.

*****************************************************  Device Defaults  ******************************************************/

#ifndef _DEVICE_DEFAULTS_H_
#define _DEVICE_DEFAULTS_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// Initialize a default structure for the Model 150 device initialization.
s_M150Devices M150Default = {
		// Frequency - REFER TO THE MODEL 150 HARDWARE REFERENCE MANUAL FOR A DETAILED DESCRIPTION.
		250,		// Carrier Frequency (MHz) - Range: 250 to 4000
		// FreqDiv2 - REFER TO THE MODEL 150 HARDWARE REFERENCE MANUAL FOR A DETAILED DESCRIPTION.
		0,		// Divide Carrier Frequency By Two - Range: 0 (disable), 1 (enable)
		// Attenuator - REFER TO THE HMC624LP4 DATASHEET FOR A DETAILED DESCRIPTION.
		0,		// Attenuation (Device Default) - Range: 0 (-31.5 dB) to 63 (0 dB)
		// RefClkOut - REFER TO THE MODEL 150 HARDWARE REFERENCE MANUAL FOR A DETAILED DESCRIPTION.
		0,		// Reference Clock Output Enable - Range: 0 (disable), 1 (enable)
		// DirectRF - REFER TO THE MODEL 150 HARDWARE REFERENCE MANUAL FOR A DETAILED DESCRIPTION.
		0,		// Direct RF Mode Enable - Range: 0 (disable), 1 (enable)
	{	// TrimDACI - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A (PDAC) Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B (NDAC) Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A (PDAC) Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B (NDAC) Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// TrimDACQ - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A (PDAC) Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B (NDAC) Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A (PDAC) Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B (NDAC) Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
};

#ifdef __cplusplus
}
#endif

#endif
